==> mastercard_qkr-1.0.1-py2-none-any.whl: mastercardqkr/externaltrans.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from resourceconfig import ResourceConfig

class ExternalTrans(BaseObject):
	"""
	
	"""

	__config = {
		
		"a04276e1-a940-422b-9c3b-15552c7a4abb" : OperationConfig("/labs/proxy/qkr2/internal/api2/externalTrans", "create", [], []),
		
		"2fd7c272-1960-40c8-acf0-5b4e0b44430e" : OperationConfig("/labs/proxy/qkr2/internal/api2/externalTrans", "query", [], []),
		
		"6bbfff5a-bfa8-4c55-8b49-f8be1ac7b6ba" : OperationConfig("/labs/proxy/qkr2/internal/api2/externalTrans/{id}", "read", [], []),
		
	}

	def getOperationConfig(self,operationUUID):
		if operationUUID not in self.__config:
			raise Exception("Invalid operationUUID: "+operationUUID)

		return self.__config[operationUUID]

	def getOperationMetadata(self):
		return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext(), ResourceConfig.getInstance().getJsonNative())


	@classmethod
	def create(cls,mapObj):
		"""
		Creates object of type ExternalTrans

		@param Dict mapObj, containing the required parameters to create a new object
		@return ExternalTrans of the response of created instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("a04276e1-a940-422b-9c3b-15552c7a4abb", ExternalTrans(mapObj))











	@classmethod
	def query(cls,criteria):
		"""
		Query objects of type ExternalTrans by id and optional criteria
		@param type criteria
		@return ExternalTrans object representing the response.
		@raise ApiException: raised an exception from the response status
		"""

		return BaseObject.execute("2fd7c272-1960-40c8-acf0-5b4e0b44430e", ExternalTrans(criteria))





	@classmethod
	def read(cls,id,criteria=None):
		"""
		Returns objects of type ExternalTrans by id and optional criteria
		@param str id
		@param dict criteria
		@return instance of ExternalTrans
		@raise ApiException: raised an exception from the response status
		"""
		mapObj =  RequestMap()
		if id:
			mapObj.set("id", id)

		if criteria:
			if (isinstance(criteria,RequestMap)):
				mapObj.setAll(criteria.getObject())
			else:
				mapObj.setAll(criteria)

		return BaseObject.execute("6bbfff5a-bfa8-4c55-8b49-f8be1ac7b6ba", ExternalTrans(mapObj))

==> mastercard_qkr-1.0.2-py2-none-any.whl: mastercardqkr/externaltrans.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from __future__ import absolute_import
from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from mastercardqkr import ResourceConfig

class ExternalTrans(BaseObject):
	"""
	
	"""

	__config = {
		
		"d84dac46-7654-45e9-a355-4ff2bc88b9de" : OperationConfig("/labs/proxy/qkr2/internal/api2/externalTrans", "create", [], []),
		
		"8326d0cd-be46-46e0-804a-d5f20cf03618" : OperationConfig("/labs/proxy/qkr2/internal/api2/externalTrans", "query", [], []),
		
		"02222add-618f-4fa6-a44d-457a32d3ca1b" : OperationConfig("/labs/proxy/qkr2/internal/api2/externalTrans/{id}", "read", [], []),
		
	}

	def getOperationConfig(self,operationUUID):
		if operationUUID not in self.__config:
			raise Exception("Invalid operationUUID: "+operationUUID)

		return self.__config[operationUUID]

	def getOperationMetadata(self):
		return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext(), ResourceConfig.getInstance().getJsonNative(), ResourceConfig.getInstance().getContentTypeOverride())


	@classmethod
	def create(cls,mapObj):
		"""
		Creates object of type ExternalTrans

		@param Dict mapObj, containing the required parameters to create a new object
		@return ExternalTrans of the response of created instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("d84dac46-7654-45e9-a355-4ff2bc88b9de", ExternalTrans(mapObj))











	@classmethod
	def query(cls,criteria):
		"""
		Query objects of type ExternalTrans by id and optional criteria
		@param type criteria
		@return ExternalTrans object representing the response.
		@raise ApiException: raised an exception from the response status
		"""

		return BaseObject.execute("8326d0cd-be46-46e0-804a-d5f20cf03618", ExternalTrans(criteria))





	@classmethod
	def read(cls,id,criteria=None):
		"""
		Returns objects of type ExternalTrans by id and optional criteria
		@param str id
		@param dict criteria
		@return instance of ExternalTrans
		@raise ApiException: raised an exception from the response status
		"""
		mapObj =  RequestMap()
		if id:
			mapObj.set("id", id)

		if criteria:
			if (isinstance(criteria,RequestMap)):
				mapObj.setAll(criteria.getObject())
			else:
				mapObj.setAll(criteria)

		return BaseObject.execute("02222add-618f-4fa6-a44d-457a32d3ca1b", ExternalTrans(mapObj))
